.. _install:

Install and configure
~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the
Openstack VmExpiration Management service, code-named os_vm_expire, on the controller node.

This section assumes that you already have a working OpenStack
environment with at least the following components installed:
.. (add the appropriate services here and further notes)

Note that installation and configuration vary by distribution.


No package available at this time for obs, only manual installation is available.
For centos and debian/ubuntu, packages can be downloaded on github in releases panel.

.. toctree::
   :maxdepth: 2

   install-manual.rst
   install-obs.rst
   install-rdo.rst
   install-ubuntu.rst
